"""This module contains the general information for EquipmentChassisProfile ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentChassisProfileConsts():
    ASSIGN_STATE_ASSIGNED = "assigned"
    ASSIGN_STATE_FAILED = "failed"
    ASSIGN_STATE_UNASSIGNED = "unassigned"
    ASSOC_STATE_ASSOCIATED = "associated"
    ASSOC_STATE_ASSOCIATING = "associating"
    ASSOC_STATE_DISASSOCIATING = "disassociating"
    ASSOC_STATE_FAILED = "failed"
    ASSOC_STATE_UNASSOCIATED = "unassociated"
    CONFIG_STATE_APPLIED = "applied"
    CONFIG_STATE_APPLYING = "applying"
    CONFIG_STATE_FAILED_TO_APPLY = "failed-to-apply"
    CONFIG_STATE_NOT_APPLIED = "not-applied"
    FSM_PREV_CONFIGURE_ANALYZE_IMPACT = "ConfigureAnalyzeImpact"
    FSM_PREV_CONFIGURE_APPLY_CONFIG = "ConfigureApplyConfig"
    FSM_PREV_CONFIGURE_APPLY_RENAME = "ConfigureApplyRename"
    FSM_PREV_CONFIGURE_APPLY_TEMPLATE = "ConfigureApplyTemplate"
    FSM_PREV_CONFIGURE_APPLY_THROTTLE = "ConfigureApplyThrottle"
    FSM_PREV_CONFIGURE_BEGIN = "ConfigureBegin"
    FSM_PREV_CONFIGURE_EVALUATE_ASSOCIATION = "ConfigureEvaluateAssociation"
    FSM_PREV_CONFIGURE_FAIL = "ConfigureFail"
    FSM_PREV_CONFIGURE_SUCCESS = "ConfigureSuccess"
    FSM_PREV_CONFIGURE_THROTTLE_WAIT = "ConfigureThrottleWait"
    FSM_PREV_CONFIGURE_WAIT_FOR_ASSOC_COMPLETION = "ConfigureWaitForAssocCompletion"
    FSM_PREV_NOP = "nop"
    FSM_RMT_INV_ERR_CODE_ERR_DIAG_CANCELLED = "ERR-DIAG-cancelled"
    FSM_RMT_INV_ERR_CODE_ERR_DIAG_FSM_RESTARTED = "ERR-DIAG-fsm-restarted"
    FSM_RMT_INV_ERR_CODE_ERR_DIAG_TEST_FAILED = "ERR-DIAG-test-failed"
    FSM_RMT_INV_ERR_CODE_ERR_DNLD_AUTHENTICATION_FAILURE = "ERR-DNLD-authentication-failure"
    FSM_RMT_INV_ERR_CODE_ERR_DNLD_ERROR = "ERR-DNLD-error"
    FSM_RMT_INV_ERR_CODE_ERR_DNLD_HOSTKEY_MISMATCH = "ERR-DNLD-hostkey-mismatch"
    FSM_RMT_INV_ERR_CODE_ERR_DNLD_INVALID_IMAGE = "ERR-DNLD-invalid-image"
    FSM_RMT_INV_ERR_CODE_ERR_DNLD_NO_FILE = "ERR-DNLD-no-file"
    FSM_RMT_INV_ERR_CODE_ERR_DNLD_NO_SPACE = "ERR-DNLD-no-space"
    FSM_RMT_INV_ERR_CODE_ERR_DNS_DELETE_ERROR = "ERR-DNS-delete-error"
    FSM_RMT_INV_ERR_CODE_ERR_DNS_GET_ERROR = "ERR-DNS-get-error"
    FSM_RMT_INV_ERR_CODE_ERR_DNS_SET_ERROR = "ERR-DNS-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_DIGEST_VALIDATION_ERROR = "ERR-Digest-Validation-error"
    FSM_RMT_INV_ERR_CODE_ERR_EXEC_GEN_CERT_ERROR = "ERR-Exec-Gen-Cert-error"
    FSM_RMT_INV_ERR_CODE_ERR_EXEC_GET_CA_CERT_ERROR = "ERR-Exec-Get-CA-Cert-error"
    FSM_RMT_INV_ERR_CODE_ERR_FILTER_ILLEGAL_FORMAT = "ERR-FILTER-illegal-format"
    FSM_RMT_INV_ERR_CODE_ERR_FSM_NO_SUCH_STATE = "ERR-FSM-no-such-state"
    FSM_RMT_INV_ERR_CODE_ERR_GET_CA_CERT_ERROR = "ERR-Get-CA-Cert-error"
    FSM_RMT_INV_ERR_CODE_ERR_GET_CERT_ERROR = "ERR-Get-Cert-error"
    FSM_RMT_INV_ERR_CODE_ERR_GET_OUT_DIGET_MESSAGE_ERROR = "ERR-Get-Out-Diget-Message-error"
    FSM_RMT_INV_ERR_CODE_ERR_HTTP_REQUEST_ERROR = "ERR-HTTP-Request-error"
    FSM_RMT_INV_ERR_CODE_ERR_HTTP_SET_ERROR = "ERR-HTTP-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_HTTPS_SET_ERROR = "ERR-HTTPS-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_IPV6_ADDR_CONFIGURED = "ERR-Ipv6-addr-configured"
    FSM_RMT_INV_ERR_CODE_ERR_MO_CONFIG_CHILD_OBJECT_CANT_BE_CONFIGURED = "ERR-MO-CONFIG-child-object-cant-be-configured"
    FSM_RMT_INV_ERR_CODE_ERR_MO_META_NO_SUCH_OBJECT_CLASS = "ERR-MO-META-no-such-object-class"
    FSM_RMT_INV_ERR_CODE_ERR_MO_PROPERTY_NO_SUCH_PROPERTY = "ERR-MO-PROPERTY-no-such-property"
    FSM_RMT_INV_ERR_CODE_ERR_MO_PROPERTY_VALUE_OUT_OF_RANGE = "ERR-MO-PROPERTY-value-out-of-range"
    FSM_RMT_INV_ERR_CODE_ERR_MO_ACCESS_DENIED = "ERR-MO-access-denied"
    FSM_RMT_INV_ERR_CODE_ERR_MO_DELETION_RULE_VIOLATION = "ERR-MO-deletion-rule-violation"
    FSM_RMT_INV_ERR_CODE_ERR_MO_DUPLICATE_OBJECT = "ERR-MO-duplicate-object"
    FSM_RMT_INV_ERR_CODE_ERR_MO_ILLEGAL_CONTAINMENT = "ERR-MO-illegal-containment"
    FSM_RMT_INV_ERR_CODE_ERR_MO_ILLEGAL_CREATION = "ERR-MO-illegal-creation"
    FSM_RMT_INV_ERR_CODE_ERR_MO_ILLEGAL_ITERATOR_STATE = "ERR-MO-illegal-iterator-state"
    FSM_RMT_INV_ERR_CODE_ERR_MO_ILLEGAL_OBJECT_LIFECYCLE_TRANSITION = "ERR-MO-illegal-object-lifecycle-transition"
    FSM_RMT_INV_ERR_CODE_ERR_MO_NAMING_RULE_VIOLATION = "ERR-MO-naming-rule-violation"
    FSM_RMT_INV_ERR_CODE_ERR_MO_OBJECT_NOT_FOUND = "ERR-MO-object-not-found"
    FSM_RMT_INV_ERR_CODE_ERR_MO_RESOURCE_ALLOCATION = "ERR-MO-resource-allocation"
    FSM_RMT_INV_ERR_CODE_ERR_NTP_DELETE_ERROR = "ERR-NTP-delete-error"
    FSM_RMT_INV_ERR_CODE_ERR_NTP_GET_ERROR = "ERR-NTP-get-error"
    FSM_RMT_INV_ERR_CODE_ERR_NTP_SET_ERROR = "ERR-NTP-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_POLICY_RESOLUTION_IN_PROGRESS = "ERR-Policy-resolution-in-progress"
    FSM_RMT_INV_ERR_CODE_ERR_TOKEN_REQUEST_DENIED = "ERR-TOKEN-request-denied"
    FSM_RMT_INV_ERR_CODE_ERR_UPDATE_VM_IP_MASK_GATEWAY_ERROR = "ERR-Update-VM-IP-Mask-Gateway-error"
    FSM_RMT_INV_ERR_CODE_ERR_AAA_CONFIG_MODIFY_ERROR = "ERR-aaa-config-modify-error"
    FSM_RMT_INV_ERR_CODE_ERR_ACCT_REALM_SET_ERROR = "ERR-acct-realm-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_ADMIN_PASSWD_SET = "ERR-admin-passwd-set"
    FSM_RMT_INV_ERR_CODE_ERR_AUTH_REALM_SET_ERROR = "ERR-auth-realm-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_AUTHENTICATION = "ERR-authentication"
    FSM_RMT_INV_ERR_CODE_ERR_AUTHORIZATION_REQUIRED = "ERR-authorization-required"
    FSM_RMT_INV_ERR_CODE_ERR_CREATE_CHASSISPACK_UNDER_DG = "ERR-create-chassispack-under-dg"
    FSM_RMT_INV_ERR_CODE_ERR_CREATE_HFP_UNDER_DG = "ERR-create-hfp-under-dg"
    FSM_RMT_INV_ERR_CODE_ERR_CREATE_KEYRING = "ERR-create-keyring"
    FSM_RMT_INV_ERR_CODE_ERR_CREATE_LOCALE = "ERR-create-locale"
    FSM_RMT_INV_ERR_CODE_ERR_CREATE_ROLE = "ERR-create-role"
    FSM_RMT_INV_ERR_CODE_ERR_CREATE_USER = "ERR-create-user"
    FSM_RMT_INV_ERR_CODE_ERR_DELETE_LOCALE = "ERR-delete-locale"
    FSM_RMT_INV_ERR_CODE_ERR_DELETE_ROLE = "ERR-delete-role"
    FSM_RMT_INV_ERR_CODE_ERR_DELETE_SESSION = "ERR-delete-session"
    FSM_RMT_INV_ERR_CODE_ERR_DELETE_USER = "ERR-delete-user"
    FSM_RMT_INV_ERR_CODE_ERR_ESTIMATE_IMPACT_ON_RECONNECT = "ERR-estimate-impact-on-reconnect"
    FSM_RMT_INV_ERR_CODE_ERR_GET_MAX_HTTP_USER_SESSIONS = "ERR-get-max-http-user-sessions"
    FSM_RMT_INV_ERR_CODE_ERR_HTTP_INITIALIZING = "ERR-http-initializing"
    FSM_RMT_INV_ERR_CODE_ERR_INTERNAL_ERROR = "ERR-internal-error"
    FSM_RMT_INV_ERR_CODE_ERR_LDAP_DELETE_ERROR = "ERR-ldap-delete-error"
    FSM_RMT_INV_ERR_CODE_ERR_LDAP_GET_ERROR = "ERR-ldap-get-error"
    FSM_RMT_INV_ERR_CODE_ERR_LDAP_GROUP_MODIFY_ERROR = "ERR-ldap-group-modify-error"
    FSM_RMT_INV_ERR_CODE_ERR_LDAP_GROUP_SET_ERROR = "ERR-ldap-group-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_LDAP_SET_ERROR = "ERR-ldap-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_LOCALE_SET_ERROR = "ERR-locale-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_MAX_USERID_SESSIONS_REACHED = "ERR-max-userid-sessions-reached"
    FSM_RMT_INV_ERR_CODE_ERR_MODIFY_LOCALE = "ERR-modify-locale"
    FSM_RMT_INV_ERR_CODE_ERR_MODIFY_ROLE = "ERR-modify-role"
    FSM_RMT_INV_ERR_CODE_ERR_MODIFY_USER = "ERR-modify-user"
    FSM_RMT_INV_ERR_CODE_ERR_MODIFY_USER_LOCALE = "ERR-modify-user-locale"
    FSM_RMT_INV_ERR_CODE_ERR_MODIFY_USER_ROLE = "ERR-modify-user-role"
    FSM_RMT_INV_ERR_CODE_ERR_NFS_DOWN = "ERR-nfs-down"
    FSM_RMT_INV_ERR_CODE_ERR_PROVIDER_GROUP_MODIFY_ERROR = "ERR-provider-group-modify-error"
    FSM_RMT_INV_ERR_CODE_ERR_PROVIDER_GROUP_SET_ERROR = "ERR-provider-group-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_RADIUS_GLOBAL_SET_ERROR = "ERR-radius-global-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_RADIUS_GROUP_SET_ERROR = "ERR-radius-group-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_RADIUS_SET_ERROR = "ERR-radius-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_ROLE_SET_ERROR = "ERR-role-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_SERVICE_NOT_READY = "ERR-service-not-ready"
    FSM_RMT_INV_ERR_CODE_ERR_SESSION_CACHE_FULL = "ERR-session-cache-full"
    FSM_RMT_INV_ERR_CODE_ERR_SESSION_NOT_FOUND = "ERR-session-not-found"
    FSM_RMT_INV_ERR_CODE_ERR_SET_PASSWORD_STRENGTH_CHECK = "ERR-set-password-strength-check"
    FSM_RMT_INV_ERR_CODE_ERR_TACACS_ENABLE_ERROR = "ERR-tacacs-enable-error"
    FSM_RMT_INV_ERR_CODE_ERR_TACACS_GLOBAL_SET_ERROR = "ERR-tacacs-global-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_TACACS_GROUP_SET_ERROR = "ERR-tacacs-group-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_TACACS_SET_ERROR = "ERR-tacacs-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_TIMEZONE_SET_ERROR = "ERR-timezone-set-error"
    FSM_RMT_INV_ERR_CODE_ERR_USER_ACCOUNT_EXPIRED = "ERR-user-account-expired"
    FSM_RMT_INV_ERR_CODE_ERR_USER_SET_ERROR = "ERR-user-set-error"
    FSM_RMT_INV_ERR_CODE_NONE = "none"
    FSM_STAMP_NEVER = "never"
    FSM_STATUS_CONFIGURE_ANALYZE_IMPACT = "ConfigureAnalyzeImpact"
    FSM_STATUS_CONFIGURE_APPLY_CONFIG = "ConfigureApplyConfig"
    FSM_STATUS_CONFIGURE_APPLY_RENAME = "ConfigureApplyRename"
    FSM_STATUS_CONFIGURE_APPLY_TEMPLATE = "ConfigureApplyTemplate"
    FSM_STATUS_CONFIGURE_APPLY_THROTTLE = "ConfigureApplyThrottle"
    FSM_STATUS_CONFIGURE_BEGIN = "ConfigureBegin"
    FSM_STATUS_CONFIGURE_EVALUATE_ASSOCIATION = "ConfigureEvaluateAssociation"
    FSM_STATUS_CONFIGURE_FAIL = "ConfigureFail"
    FSM_STATUS_CONFIGURE_SUCCESS = "ConfigureSuccess"
    FSM_STATUS_CONFIGURE_THROTTLE_WAIT = "ConfigureThrottleWait"
    FSM_STATUS_CONFIGURE_WAIT_FOR_ASSOC_COMPLETION = "ConfigureWaitForAssocCompletion"
    FSM_STATUS_NOP = "nop"
    INT_ID_NONE = "none"
    OPER_STATE_CHASSIS_FAILED = "chassis-failed"
    OPER_STATE_CHASSIS_MISMATCH = "chassis-mismatch"
    OPER_STATE_CONFIG = "config"
    OPER_STATE_CONFIG_FAILURE = "config-failure"
    OPER_STATE_DECOMISSIONING = "decomissioning"
    OPER_STATE_DEGRADED = "degraded"
    OPER_STATE_DIAGNOSTICS = "diagnostics"
    OPER_STATE_DIAGNOSTICS_FAILED = "diagnostics-failed"
    OPER_STATE_DISABLED = "disabled"
    OPER_STATE_DISCOVERY = "discovery"
    OPER_STATE_DISCOVERY_FAILED = "discovery-failed"
    OPER_STATE_INACCESSIBLE = "inaccessible"
    OPER_STATE_INDETERMINATE = "indeterminate"
    OPER_STATE_INOPERABLE = "inoperable"
    OPER_STATE_MAINTENANCE = "maintenance"
    OPER_STATE_MAINTENANCE_FAILED = "maintenance-failed"
    OPER_STATE_OK = "ok"
    OPER_STATE_OPERABLE = "operable"
    OPER_STATE_PENDING_REASSOCIATION = "pending-reassociation"
    OPER_STATE_PENDING_REBOOT = "pending-reboot"
    OPER_STATE_POWER_OFF = "power-off"
    OPER_STATE_REMOVED = "removed"
    OPER_STATE_RESTART = "restart"
    OPER_STATE_TEST = "test"
    OPER_STATE_TEST_FAILED = "test-failed"
    OPER_STATE_UNASSOCIATED = "unassociated"
    OPER_STATE_UNCONFIG = "unconfig"
    OPER_STATE_UNCONFIG_FAILED = "unconfig-failed"
    OWNER_MANAGEMENT = "management"
    OWNER_POLICY = "policy"
    OWNER_TIER = "tier"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"
    RESOLVE_REMOTE_NO = "no"
    RESOLVE_REMOTE_YES = "yes"
    TYPE_INITIAL_TEMPLATE = "initial-template"
    TYPE_INSTANCE = "instance"
    TYPE_UPDATING_TEMPLATE = "updating-template"


class EquipmentChassisProfile(ManagedObject):
    """This is EquipmentChassisProfile class."""

    consts = EquipmentChassisProfileConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("EquipmentChassisProfile", "equipmentChassisProfile", "cp-[name]", VersionMeta.Version151a, "InputOutput", 0x7fff, [], ["admin", "pn-equipment", "pn-maintenance", "pn-policy"], ['equipmentTemplate', 'equipmentTier', 'orgOrg'], ['computeChassisFeatMask', 'cpmaintAck', 'equipmentBinding', 'equipmentCPMeta', 'equipmentChassisIssues', 'equipmentChassisProfileAssocCtx', 'equipmentChassisProfileFsm', 'equipmentChassisProfileFsmTask', 'equipmentRequirement', 'eventInst', 'faultInst', 'lstorageDiskZoningConfigDef'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "assign_state": MoPropertyMeta("assign_state", "assignState", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["assigned", "failed", "unassigned"], []), 
        "assoc_state": MoPropertyMeta("assoc_state", "assocState", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["associated", "associating", "disassociating", "failed", "unassociated"], []), 
        "chassis_dn": MoPropertyMeta("chassis_dn", "chassisDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "chassis_fw_policy_name": MoPropertyMeta("chassis_fw_policy_name", "chassisFwPolicyName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "compute_conn_policy_name": MoPropertyMeta("compute_conn_policy_name", "computeConnPolicyName", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "config_qualifier": MoPropertyMeta("config_qualifier", "configQualifier", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|chassis-profile-not-supported|migration|firmware-version-mismatch|non-interrupt-fsm-running|insufficient-resources|compute-conn-invalid-hw-config|physical-requirement|chassis-undiscovered|chassis-feature-capability-mismatch|resource-ownership-conflict|compute-conn-unsupported-cmc-version|chassis-unavailable|invalid-chassis-pack|missing-firmware-image|chassis-feature-capability-mismatch-non-fatal|compute-second-controller-unsupported-cmc-version|insufficient-power-budget),){0,18}(defaultValue|not-applicable|chassis-profile-not-supported|migration|firmware-version-mismatch|non-interrupt-fsm-running|insufficient-resources|compute-conn-invalid-hw-config|physical-requirement|chassis-undiscovered|chassis-feature-capability-mismatch|resource-ownership-conflict|compute-conn-unsupported-cmc-version|chassis-unavailable|invalid-chassis-pack|missing-firmware-image|chassis-feature-capability-mismatch-non-fatal|compute-second-controller-unsupported-cmc-version|insufficient-power-budget){0,1}""", [], []), 
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["applied", "applying", "failed-to-apply", "not-applied"], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "disk_zoning_policy_name": MoPropertyMeta("disk_zoning_policy_name", "diskZoningPolicyName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "domain": MoPropertyMeta("domain", "domain", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "domain_dn": MoPropertyMeta("domain_dn", "domainDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "domain_group": MoPropertyMeta("domain_group", "domainGroup", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "domain_group_dn": MoPropertyMeta("domain_group_dn", "domainGroupDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, [], []), 
        "fsm_descr": MoPropertyMeta("fsm_descr", "fsmDescr", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, [], []), 
        "fsm_flags": MoPropertyMeta("fsm_flags", "fsmFlags", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, [], ["0-4294967295"]), 
        "fsm_prev": MoPropertyMeta("fsm_prev", "fsmPrev", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, ["ConfigureAnalyzeImpact", "ConfigureApplyConfig", "ConfigureApplyRename", "ConfigureApplyTemplate", "ConfigureApplyThrottle", "ConfigureBegin", "ConfigureEvaluateAssociation", "ConfigureFail", "ConfigureSuccess", "ConfigureThrottleWait", "ConfigureWaitForAssocCompletion", "nop"], []), 
        "fsm_progr": MoPropertyMeta("fsm_progr", "fsmProgr", "byte", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, [], ["0-100"]), 
        "fsm_rmt_inv_err_code": MoPropertyMeta("fsm_rmt_inv_err_code", "fsmRmtInvErrCode", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, ["ERR-DIAG-cancelled", "ERR-DIAG-fsm-restarted", "ERR-DIAG-test-failed", "ERR-DNLD-authentication-failure", "ERR-DNLD-error", "ERR-DNLD-hostkey-mismatch", "ERR-DNLD-invalid-image", "ERR-DNLD-no-file", "ERR-DNLD-no-space", "ERR-DNS-delete-error", "ERR-DNS-get-error", "ERR-DNS-set-error", "ERR-Digest-Validation-error", "ERR-Exec-Gen-Cert-error", "ERR-Exec-Get-CA-Cert-error", "ERR-FILTER-illegal-format", "ERR-FSM-no-such-state", "ERR-Get-CA-Cert-error", "ERR-Get-Cert-error", "ERR-Get-Out-Diget-Message-error", "ERR-HTTP-Request-error", "ERR-HTTP-set-error", "ERR-HTTPS-set-error", "ERR-Ipv6-addr-configured", "ERR-MO-CONFIG-child-object-cant-be-configured", "ERR-MO-META-no-such-object-class", "ERR-MO-PROPERTY-no-such-property", "ERR-MO-PROPERTY-value-out-of-range", "ERR-MO-access-denied", "ERR-MO-deletion-rule-violation", "ERR-MO-duplicate-object", "ERR-MO-illegal-containment", "ERR-MO-illegal-creation", "ERR-MO-illegal-iterator-state", "ERR-MO-illegal-object-lifecycle-transition", "ERR-MO-naming-rule-violation", "ERR-MO-object-not-found", "ERR-MO-resource-allocation", "ERR-NTP-delete-error", "ERR-NTP-get-error", "ERR-NTP-set-error", "ERR-Policy-resolution-in-progress", "ERR-TOKEN-request-denied", "ERR-Update-VM-IP-Mask-Gateway-error", "ERR-aaa-config-modify-error", "ERR-acct-realm-set-error", "ERR-admin-passwd-set", "ERR-auth-realm-set-error", "ERR-authentication", "ERR-authorization-required", "ERR-create-chassispack-under-dg", "ERR-create-hfp-under-dg", "ERR-create-keyring", "ERR-create-locale", "ERR-create-role", "ERR-create-user", "ERR-delete-locale", "ERR-delete-role", "ERR-delete-session", "ERR-delete-user", "ERR-estimate-impact-on-reconnect", "ERR-get-max-http-user-sessions", "ERR-http-initializing", "ERR-internal-error", "ERR-ldap-delete-error", "ERR-ldap-get-error", "ERR-ldap-group-modify-error", "ERR-ldap-group-set-error", "ERR-ldap-set-error", "ERR-locale-set-error", "ERR-max-userid-sessions-reached", "ERR-modify-locale", "ERR-modify-role", "ERR-modify-user", "ERR-modify-user-locale", "ERR-modify-user-role", "ERR-nfs-down", "ERR-provider-group-modify-error", "ERR-provider-group-set-error", "ERR-radius-global-set-error", "ERR-radius-group-set-error", "ERR-radius-set-error", "ERR-role-set-error", "ERR-service-not-ready", "ERR-session-cache-full", "ERR-session-not-found", "ERR-set-password-strength-check", "ERR-tacacs-enable-error", "ERR-tacacs-global-set-error", "ERR-tacacs-group-set-error", "ERR-tacacs-set-error", "ERR-timezone-set-error", "ERR-user-account-expired", "ERR-user-set-error", "none"], ["0-4294967295"]), 
        "fsm_rmt_inv_err_descr": MoPropertyMeta("fsm_rmt_inv_err_descr", "fsmRmtInvErrDescr", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, 0, 510, None, [], []), 
        "fsm_rmt_inv_rslt": MoPropertyMeta("fsm_rmt_inv_rslt", "fsmRmtInvRslt", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((defaultValue|not-applicable|resource-unavailable|service-unavailable|intermittent-error|sw-defect|service-not-implemented-ignore|extend-timeout|capability-not-implemented-failure|illegal-fru|end-point-unavailable|failure|resource-capacity-exceeded|service-protocol-error|fw-defect|service-not-implemented-fail|task-reset|unidentified-fail|capability-not-supported|end-point-failed|fru-state-indeterminate|resource-dependency|fru-identity-indeterminate|internal-error|hw-defect|service-not-supported|fru-not-supported|end-point-protocol-error|capability-unavailable|fru-not-ready|capability-not-implemented-ignore|fru-info-malformed|timeout),){0,32}(defaultValue|not-applicable|resource-unavailable|service-unavailable|intermittent-error|sw-defect|service-not-implemented-ignore|extend-timeout|capability-not-implemented-failure|illegal-fru|end-point-unavailable|failure|resource-capacity-exceeded|service-protocol-error|fw-defect|service-not-implemented-fail|task-reset|unidentified-fail|capability-not-supported|end-point-failed|fru-state-indeterminate|resource-dependency|fru-identity-indeterminate|internal-error|hw-defect|service-not-supported|fru-not-supported|end-point-protocol-error|capability-unavailable|fru-not-ready|capability-not-implemented-ignore|fru-info-malformed|timeout){0,1}""", [], []), 
        "fsm_stage_descr": MoPropertyMeta("fsm_stage_descr", "fsmStageDescr", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, [], []), 
        "fsm_stamp": MoPropertyMeta("fsm_stamp", "fsmStamp", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []), 
        "fsm_status": MoPropertyMeta("fsm_status", "fsmStatus", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, ["ConfigureAnalyzeImpact", "ConfigureApplyConfig", "ConfigureApplyRename", "ConfigureApplyTemplate", "ConfigureApplyThrottle", "ConfigureBegin", "ConfigureEvaluateAssociation", "ConfigureFail", "ConfigureSuccess", "ConfigureThrottleWait", "ConfigureWaitForAssocCompletion", "nop"], []), 
        "fsm_try": MoPropertyMeta("fsm_try", "fsmTry", "byte", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, [], []), 
        "guid": MoPropertyMeta("guid", "guid", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x40, 0, 510, None, [], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "ls_dn": MoPropertyMeta("ls_dn", "lsDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "maint_policy_name": MoPropertyMeta("maint_policy_name", "maintPolicyName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version151a, MoPropertyMeta.NAMING, 0x100, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "oper_chassis_fw_policy_name": MoPropertyMeta("oper_chassis_fw_policy_name", "operChassisFwPolicyName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "oper_compute_conn_policy_name": MoPropertyMeta("oper_compute_conn_policy_name", "operComputeConnPolicyName", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "oper_disk_zoning_policy_name": MoPropertyMeta("oper_disk_zoning_policy_name", "operDiskZoningPolicyName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "oper_maint_policy_name": MoPropertyMeta("oper_maint_policy_name", "operMaintPolicyName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "oper_src_templ_name": MoPropertyMeta("oper_src_templ_name", "operSrcTemplName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["chassis-failed", "chassis-mismatch", "config", "config-failure", "decomissioning", "degraded", "diagnostics", "diagnostics-failed", "disabled", "discovery", "discovery-failed", "inaccessible", "indeterminate", "inoperable", "maintenance", "maintenance-failed", "ok", "operable", "pending-reassociation", "pending-reboot", "power-off", "removed", "restart", "test", "test-failed", "unassociated", "unconfig", "unconfig-failed"], []), 
        "owner": MoPropertyMeta("owner", "owner", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["management", "policy", "tier"], []), 
        "pn_dn": MoPropertyMeta("pn_dn", "pnDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "resolve_remote": MoPropertyMeta("resolve_remote", "resolveRemote", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["no", "yes"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x400, 0, 256, None, [], []), 
        "src_templ_name": MoPropertyMeta("src_templ_name", "srcTemplName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version151a, MoPropertyMeta.CREATE_ONLY, 0x2000, None, None, None, ["initial-template", "instance", "updating-template"], []), 
        "usr_lbl": MoPropertyMeta("usr_lbl", "usrLbl", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x4000, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,32}""", [], []), 
        "uuid": MoPropertyMeta("uuid", "uuid", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""(([0-9a-fA-F]){8}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){12})|0""", [], []), 
    }

    prop_map = {
        "assignState": "assign_state", 
        "assocState": "assoc_state", 
        "chassisDn": "chassis_dn", 
        "chassisFwPolicyName": "chassis_fw_policy_name", 
        "childAction": "child_action", 
        "computeConnPolicyName": "compute_conn_policy_name", 
        "configQualifier": "config_qualifier", 
        "configState": "config_state", 
        "descr": "descr", 
        "diskZoningPolicyName": "disk_zoning_policy_name", 
        "dn": "dn", 
        "domain": "domain", 
        "domainDn": "domain_dn", 
        "domainGroup": "domain_group", 
        "domainGroupDn": "domain_group_dn", 
        "fltAggr": "flt_aggr", 
        "fsmDescr": "fsm_descr", 
        "fsmFlags": "fsm_flags", 
        "fsmPrev": "fsm_prev", 
        "fsmProgr": "fsm_progr", 
        "fsmRmtInvErrCode": "fsm_rmt_inv_err_code", 
        "fsmRmtInvErrDescr": "fsm_rmt_inv_err_descr", 
        "fsmRmtInvRslt": "fsm_rmt_inv_rslt", 
        "fsmStageDescr": "fsm_stage_descr", 
        "fsmStamp": "fsm_stamp", 
        "fsmStatus": "fsm_status", 
        "fsmTry": "fsm_try", 
        "guid": "guid", 
        "intId": "int_id", 
        "lsDn": "ls_dn", 
        "maintPolicyName": "maint_policy_name", 
        "name": "name", 
        "operChassisFwPolicyName": "oper_chassis_fw_policy_name", 
        "operComputeConnPolicyName": "oper_compute_conn_policy_name", 
        "operDiskZoningPolicyName": "oper_disk_zoning_policy_name", 
        "operMaintPolicyName": "oper_maint_policy_name", 
        "operSrcTemplName": "oper_src_templ_name", 
        "operState": "oper_state", 
        "owner": "owner", 
        "pnDn": "pn_dn", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "resolveRemote": "resolve_remote", 
        "rn": "rn", 
        "srcTemplName": "src_templ_name", 
        "status": "status", 
        "type": "type", 
        "usrLbl": "usr_lbl", 
        "uuid": "uuid", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.assign_state = None
        self.assoc_state = None
        self.chassis_dn = None
        self.chassis_fw_policy_name = None
        self.child_action = None
        self.compute_conn_policy_name = None
        self.config_qualifier = None
        self.config_state = None
        self.descr = None
        self.disk_zoning_policy_name = None
        self.domain = None
        self.domain_dn = None
        self.domain_group = None
        self.domain_group_dn = None
        self.flt_aggr = None
        self.fsm_descr = None
        self.fsm_flags = None
        self.fsm_prev = None
        self.fsm_progr = None
        self.fsm_rmt_inv_err_code = None
        self.fsm_rmt_inv_err_descr = None
        self.fsm_rmt_inv_rslt = None
        self.fsm_stage_descr = None
        self.fsm_stamp = None
        self.fsm_status = None
        self.fsm_try = None
        self.guid = None
        self.int_id = None
        self.ls_dn = None
        self.maint_policy_name = None
        self.oper_chassis_fw_policy_name = None
        self.oper_compute_conn_policy_name = None
        self.oper_disk_zoning_policy_name = None
        self.oper_maint_policy_name = None
        self.oper_src_templ_name = None
        self.oper_state = None
        self.owner = None
        self.pn_dn = None
        self.policy_level = None
        self.policy_owner = None
        self.resolve_remote = None
        self.src_templ_name = None
        self.status = None
        self.type = None
        self.usr_lbl = None
        self.uuid = None

        ManagedObject.__init__(self, "EquipmentChassisProfile", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ComputeFabricEthMonSrcEp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ComputeFabricEthMonSrcEpConsts():
    DIRECTION_BOTH = "both"
    DIRECTION_RX = "rx"
    DIRECTION_TX = "tx"


class ComputeFabricEthMonSrcEp(ManagedObject):
    """This is ComputeFabricEthMonSrcEp class."""

    consts = ComputeFabricEthMonSrcEpConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("ComputeFabricEthMonSrcEp", "computeFabricEthMonSrcEp", "src-[id]", VersionMeta.Version201b, "InputOutput", 0xff, [], ["admin", "ext-lan-config", "ext-lan-policy"], ['computeFabricEthMonSrcEpCont'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "direction": MoPropertyMeta("direction", "direction", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["both", "rx", "tx"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version201b, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []), 
        "mo_dn": MoPropertyMeta("mo_dn", "moDn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "session": MoPropertyMeta("session", "session", "uint", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], ["1-255"]), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "direction": "direction", 
        "dn": "dn", 
        "id": "id", 
        "moDn": "mo_dn", 
        "name": "name", 
        "rn": "rn", 
        "session": "session", 
        "status": "status", 
        "transport": "transport", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.direction = None
        self.mo_dn = None
        self.name = None
        self.session = None
        self.status = None
        self.transport = None
        self.type = None

        ManagedObject.__init__(self, "ComputeFabricEthMonSrcEp", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigLunItem ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigLunItemConsts():
    BLOCK_SIZE_512 = "512"
    BLOCK_SIZE_UNKNOWN = "unknown"
    BOOTABLE_FALSE = "false"
    BOOTABLE_TRUE = "true"
    BOOTABLE_UNKNOWN = "unknown"
    CONFIG_STATE_N_A = "N/A"
    CONFIG_STATE_APPLIED = "applied"
    CONFIG_STATE_APPLY_FAILED = "apply-failed"
    CONFIG_STATE_APPLYING = "applying"
    CONFIG_STATE_NOT_APPLIED = "not-applied"
    CONFIG_STATE_NOT_IN_USE = "not-in-use"
    CONFIG_STATE_ORPHANED = "orphaned"
    CONFIG_STATE_UNKNOWN = "unknown"
    DRIVE_STATE_CACHE_DEGRADED = "cache-degraded"
    DRIVE_STATE_DEGRADED = "degraded"
    DRIVE_STATE_OFFLINE = "offline"
    DRIVE_STATE_OPTIMAL = "optimal"
    DRIVE_STATE_PARTIALLY_DEGRADED = "partially-degraded"
    DRIVE_STATE_REBUILDING = "rebuilding"
    DRIVE_STATE_UNKNOWN = "unknown"
    EQUIPMENT_TYPE_CHASSIS = "chassis"
    EQUIPMENT_TYPE_FABRIC_INTERCONNECT = "fabricInterconnect"
    EQUIPMENT_TYPE_FEX = "fex"
    EQUIPMENT_TYPE_SERVER = "server"
    NUMBER_OF_BLOCKS_UNKNOWN = "unknown"
    OPER_STATE_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPER_STATE_AUTO_UPGRADE = "auto-upgrade"
    OPER_STATE_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPER_STATE_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPER_STATE_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPER_STATE_CONFIG = "config"
    OPER_STATE_DECOMISSIONING = "decomissioning"
    OPER_STATE_DEGRADED = "degraded"
    OPER_STATE_DISABLED = "disabled"
    OPER_STATE_DISCOVERY = "discovery"
    OPER_STATE_DISCOVERY_FAILED = "discovery-failed"
    OPER_STATE_EQUIPMENT_PROBLEM = "equipment-problem"
    OPER_STATE_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPER_STATE_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPER_STATE_IDENTIFY = "identify"
    OPER_STATE_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPER_STATE_INOPERABLE = "inoperable"
    OPER_STATE_MALFORMED_FRU = "malformed-fru"
    OPER_STATE_NOT_SUPPORTED = "not-supported"
    OPER_STATE_OPERABLE = "operable"
    OPER_STATE_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPER_STATE_PERFORMANCE_PROBLEM = "performance-problem"
    OPER_STATE_POST_FAILURE = "post-failure"
    OPER_STATE_POWER_PROBLEM = "power-problem"
    OPER_STATE_POWERED_OFF = "powered-off"
    OPER_STATE_REMOVED = "removed"
    OPER_STATE_THERMAL_PROBLEM = "thermal-problem"
    OPER_STATE_UNKNOWN = "unknown"
    OPER_STATE_UPGRADE_PROBLEM = "upgrade-problem"
    OPER_STATE_VOLTAGE_PROBLEM = "voltage-problem"
    PRESENCE_EMPTY = "empty"
    PRESENCE_EQUIPPED = "equipped"
    PRESENCE_EQUIPPED_IDENTITY_UNESTABLISHABLE = "equipped-identity-unestablishable"
    PRESENCE_EQUIPPED_NOT_PRIMARY = "equipped-not-primary"
    PRESENCE_EQUIPPED_SLAVE = "equipped-slave"
    PRESENCE_EQUIPPED_UNSUPPORTED = "equipped-unsupported"
    PRESENCE_EQUIPPED_WITH_MALFORMED_FRU = "equipped-with-malformed-fru"
    PRESENCE_INACCESSIBLE = "inaccessible"
    PRESENCE_MISMATCH = "mismatch"
    PRESENCE_MISMATCH_IDENTITY_UNESTABLISHABLE = "mismatch-identity-unestablishable"
    PRESENCE_MISMATCH_SLAVE = "mismatch-slave"
    PRESENCE_MISSING = "missing"
    PRESENCE_MISSING_SLAVE = "missing-slave"
    PRESENCE_NOT_SUPPORTED = "not-supported"
    PRESENCE_UNAUTHORIZED = "unauthorized"
    PRESENCE_UNKNOWN = "unknown"


class ConfigLunItem(ManagedObject):
    """This is ConfigLunItem class."""

    consts = ConfigLunItemConsts()
    naming_props = set([])

    mo_meta = MoMeta("ConfigLunItem", "configLunItem", "lun-item", VersionMeta.Version141a, "InputOutput", 0xf, [], ["read-only"], [], [], [None])

    prop_meta = {
        "affected_sp": MoPropertyMeta("affected_sp", "affectedSP", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "block_size": MoPropertyMeta("block_size", "blockSize", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["512", "unknown"], ["0-4294967295"]), 
        "bootable": MoPropertyMeta("bootable", "bootable", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "true", "unknown"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "component_dn": MoPropertyMeta("component_dn", "componentDn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A", "applied", "apply-failed", "applying", "not-applied", "not-in-use", "orphaned", "unknown"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "domain_group_dn": MoPropertyMeta("domain_group_dn", "domainGroupDn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "domain_name": MoPropertyMeta("domain_name", "domainName", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "drive_state": MoPropertyMeta("drive_state", "driveState", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["cache-degraded", "degraded", "offline", "optimal", "partially-degraded", "rebuilding", "unknown"], []), 
        "equipment_type": MoPropertyMeta("equipment_type", "equipmentType", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["chassis", "fabricInterconnect", "fex", "server"], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "location": MoPropertyMeta("location", "location", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "number_of_blocks": MoPropertyMeta("number_of_blocks", "numberOfBlocks", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unknown"], ["0-4294967295"]), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "malformed-fru", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "upgrade-problem", "voltage-problem"], []), 
        "presence": MoPropertyMeta("presence", "presence", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "equipped", "equipped-identity-unestablishable", "equipped-not-primary", "equipped-slave", "equipped-unsupported", "equipped-with-malformed-fru", "inaccessible", "mismatch", "mismatch-identity-unestablishable", "mismatch-slave", "missing", "missing-slave", "not-supported", "unauthorized", "unknown"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "size": MoPropertyMeta("size", "size", "ulong", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "storage_profile": MoPropertyMeta("storage_profile", "storageProfile", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
    }

    prop_map = {
        "affectedSP": "affected_sp", 
        "blockSize": "block_size", 
        "bootable": "bootable", 
        "childAction": "child_action", 
        "componentDn": "component_dn", 
        "configState": "config_state", 
        "dn": "dn", 
        "domainGroupDn": "domain_group_dn", 
        "domainName": "domain_name", 
        "driveState": "drive_state", 
        "equipmentType": "equipment_type", 
        "id": "id", 
        "location": "location", 
        "name": "name", 
        "numberOfBlocks": "number_of_blocks", 
        "operState": "oper_state", 
        "presence": "presence", 
        "rn": "rn", 
        "size": "size", 
        "status": "status", 
        "storageProfile": "storage_profile", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.affected_sp = None
        self.block_size = None
        self.bootable = None
        self.child_action = None
        self.component_dn = None
        self.config_state = None
        self.domain_group_dn = None
        self.domain_name = None
        self.drive_state = None
        self.equipment_type = None
        self.id = None
        self.location = None
        self.name = None
        self.number_of_blocks = None
        self.oper_state = None
        self.presence = None
        self.size = None
        self.status = None
        self.storage_profile = None

        ManagedObject.__init__(self, "ConfigLunItem", parent_mo_or_dn, **kwargs)




# Copyright 2013 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This module contains the APIs used to create and download tech_support file.
"""

import os
import time
import datetime
import logging
from ..ucscexception import UcscValidationException, \
    UcscWarning, \
    UcscOperationError
from ..mometa.sysdebug.SysdebugTechSupportCmdOpt import \
    SysdebugTechSupportCmdOpt, SysdebugTechSupportCmdOptConsts

log = logging.getLogger('ucscentral')


def _validate_download_args(file_dir, file_name):
    if file_dir is None:
        raise UcscValidationException(
            'file_dir is a required parameter')

    if file_name is None:
        raise UcscValidationException(
            'file_name is a required parameter')

    if not file_name.endswith('.tar'):
        raise UcscValidationException('file_name should end with .tar')


def _create_download_dir(file_dir):
    if not os.path.exists(file_dir):
        os.makedirs(file_dir)


def _get_creation_ts():
    dt1 = datetime.datetime(1970, 1, 1, 12, 0, 0, 0)
    dt2 = datetime.datetime.utcnow()
    return int((dt2 - dt1).total_seconds())


def _bootstrap_tech_support_mo(creation_ts):
    from ..mometa.top.TopSystem import TopSystem
    from ..mometa.sysdebug.SysdebugTechSupport import SysdebugTechSupport, \
        SysdebugTechSupportConsts
    from ..mometa.sysdebug.SysdebugTechSupFileRepository import \
        SysdebugTechSupFileRepository

    top_system = TopSystem()
    ts_file_repo = SysdebugTechSupFileRepository(parent_mo_or_dn=top_system)
    ts_mo = SysdebugTechSupport(
        parent_mo_or_dn=ts_file_repo,
        creation_ts=str(creation_ts),
        admin_state=SysdebugTechSupportConsts.ADMIN_STATE_START)
    return ts_mo


def _bootstrap_domain_tech_support_mo(creation_ts, domain_dn):
    from ..mometa.sysdebug.SysdebugTechSupportOp import \
        SysdebugTechSupportOp, SysdebugTechSupportOpConsts
    from ..mometa.sysdebug.SysdebugTechSupFileRepository import \
        SysdebugTechSupFileRepository

    ts_domain_file_repo = SysdebugTechSupFileRepository(
        parent_mo_or_dn=domain_dn)
    ts_domain_mo = SysdebugTechSupportOp(
        parent_mo_or_dn=ts_domain_file_repo,
        creation_ts=str(creation_ts),
        admin_state=SysdebugTechSupportOpConsts.ADMIN_STATE_START)
    return ts_domain_mo


def _check_for_failure(err):
    # The following error messages define the criteria for
    # the poll loop to be interrupted by an exception.
    # There are occasinal Request Timeouts, which could be ignored
    # if the subsequent calls are being replied to by the server.
    failure_conditions = ["urlopen error",
                          "TechSupport creation timed out",
                          "TechSupport creation failed"]
    for each in failure_conditions:
        if each in str(err):
            raise


def _fail_and_remove_ts(handle, ts_mo, err):
    if ts_mo:
        handle.remove_mo(ts_mo)
        handle.commit()
    raise UcscOperationError("Techsupport creation", err)


def _fail_and_remove_domain_ts(handle, ts_mo, err):
    # In case of domain ts remove, just set the mo, backend will remove it
    # from domain
    if ts_mo:
        ts_mo.admin_state = "delete"
        handle.set_mo(ts_mo)
        handle.commit()
    raise UcscOperationError("Domain techsupport creation", err)


def poll_wait_for_tech_support(handle, ts_mo, timeout):
    from ..mometa.sysdebug.SysdebugTechSupport import \
        SysdebugTechSupportConsts as tsconsts

    poll_interval = 5
    duration = timeout
    while True:
        try:
            ts = handle.query_dn(ts_mo.dn)
            if ts is None:
                _fail_and_remove_ts(handle, ts, 'failed')
            if ts.oper_state == tsconsts.OPER_STATE_AVAILABLE:
                break
            if ts.oper_state == tsconsts.OPER_STATE_FAILED or \
                    ts.oper_state == tsconsts.OPER_STATE_UNAVAILABLE:
                _fail_and_remove_ts(handle, ts, 'failed')
            time.sleep(min(duration, poll_interval))
            duration = max(0, (duration - poll_interval))
            if duration == 0:
                _fail_and_remove_ts(
                    handle, ts, 'timed out')
        except Exception as err:
            _check_for_failure(err)
    return ts


def download_tech_support(handle, name, file_dir, file_name):
    try:
        handle.file_download(url_suffix="techsupport/" + name,
                             file_dir=str(file_dir),
                             file_name=str(file_name))
    except Exception as err:
        UcscWarning(str(err))


def _remove_tech_support(handle, ts_mo):
    ts_mo.admin_state = "delete"
    handle.set_mo(ts_mo)
    handle.commit()


def get_tech_support(handle, file_dir=None, file_name=None,
                     remove_from_ucsc=False,
                     download=True,
                     timeout=1200):
    """
    This operation creates the technical support file for UcsCentral.

    Args:
        handle (UcscHandle): UcsCentral connection handle
        file_dir (str): directory to download techsupport file to
        file_name (str): name for the backup file
        remove_from_ucsc (boolean): True/False, False - by default
        download (boolean): True/False, True - by default
        timeout (number) : time in seconds for which method waits
                           for the techsupport to generate before it exits.
    Example:
        file_dir = "/home/user/backup"\n
        file_name = "techsupport.tar"\n
        get_tech_support(handle, file_dir=file_dir, file_name=file_name)

    """

    if download:
        _validate_download_args(file_dir, file_name)
        _create_download_dir(file_dir)

    ts_mo = _bootstrap_tech_support_mo(_get_creation_ts())
    SysdebugTechSupportCmdOpt(parent_mo_or_dn=ts_mo)

    handle.add_mo(ts_mo)
    handle.commit()

    log.debug("Techsupport creation started")

    # poll for tech support to complete
    ts_mo = poll_wait_for_tech_support(handle, ts_mo, timeout)

    log.debug("Techsupport creation completed")
    # download tech support file
    if download:
        if handle.is_local_download_supported():
            download_tech_support(handle, ts_mo.name, file_dir, file_name)
            log.debug("Downloading techsupport complete")
        else:
            log.debug("Local download is not supported for this "
                      "UcsCentral version")

    # remove tech support file from Ucs Central
    if remove_from_ucsc:
        _remove_tech_support(handle, ts_mo)
        log.debug("Removed techsupport from UcsCentral")


def _is_valid_arg(param, kwargs):
    return param in kwargs and kwargs[param] is not None


def _set_ts_options_ucsm(ts_cmd_opt, kwargs):
    ts_cmd_opt.major_opt_type = \
        SysdebugTechSupportCmdOptConsts.MAJOR_OPT_TYPE_UCSM


def _set_ts_options_ucsm_mgmt(ts_cmd_opt, kwargs):
    ts_cmd_opt.major_opt_type = \
        SysdebugTechSupportCmdOptConsts.MAJOR_OPT_TYPE_UCSM_MGMT


def _validate_chassis_options(kwargs):
    if not _is_valid_arg("chassis_id", kwargs):
        raise UcscValidationException('chassis_id should be specified')
    if "cimc_id" not in kwargs and \
            "iom_id" not in kwargs and \
            "cartridge_id" not in kwargs:
        raise UcscValidationException(
            'cimc_id/iom_id/cartridge_id should be specified')


def _set_ts_options_chassis(ts_cmd_opt, kwargs):
    _validate_chassis_options(kwargs)
    ts_cmd_opt.chassis_id = str(kwargs["chassis_id"])
    ts_cmd_opt.major_opt_type = \
        SysdebugTechSupportCmdOptConsts.MAJOR_OPT_TYPE_CHASSIS
    if _is_valid_arg("cimc_id", kwargs):
        ts_cmd_opt.chassis_cimc_id = str(kwargs["cimc_id"])

        if _is_valid_arg("adapter_id", kwargs):
            ts_cmd_opt.cimc_adapter_id = str(kwargs["adapter_id"])
        else:
            ts_cmd_opt.cimc_adapter_id = \
                SysdebugTechSupportCmdOptConsts.CIMC_ADAPTER_ID_ALL
    elif _is_valid_arg("iom_id", kwargs):
        ts_cmd_opt.chassis_iom_id = str(kwargs["iom_id"])
    elif _is_valid_arg("cartridge_id", kwargs):
        ts_cmd_opt.chassis_cartridge_id = str(kwargs["cartridge_id"])
        if ts_cmd_opt.chassis_cartridge_id != "all":
            if _is_valid_arg("cartridge_cimc_id", kwargs):
                ts_cmd_opt.cartridge_cimc_id = str(
                    kwargs["cartridge_cimc_id"])
            else:
                raise UcscValidationException(
                    'cartridge_cimc_id should be specified')


def _validate_rackserver_options(kwargs):
    if not _is_valid_arg("rack_server_id", kwargs):
        raise UcscValidationException(
            'rack_server_id should be specified')


def _set_ts_options_rackserver(ts_cmd_opt, kwargs):
    _validate_rackserver_options(kwargs)
    ts_cmd_opt.rack_server_id = str(kwargs["rack_server_id"])
    ts_cmd_opt.major_opt_type = \
        SysdebugTechSupportCmdOptConsts.MAJOR_OPT_TYPE_SERVER

    if _is_valid_arg("rack_adapter_id", kwargs):
        ts_cmd_opt.rack_server_adapter_id = str(kwargs["rack_adapter_id"])
    else:
        ts_cmd_opt.rack_server_adapter_id = \
            SysdebugTechSupportCmdOptConsts.RACK_SERVER_ADAPTER_ID_ALL


def _validate_fex_options(kwargs):
    if not _is_valid_arg("fex_id", kwargs):
        raise UcscValidationException('fex_id should be specified')


def _set_ts_options_fex(ts_cmd_opt, kwargs):
    _validate_fex_options(kwargs)
    ts_cmd_opt.fab_ext_id = str(kwargs["fex_id"])
    ts_cmd_opt.major_opt_type = \
        SysdebugTechSupportCmdOptConsts.MAJOR_OPT_TYPE_FEX


def _validate_servermemory_options(kwargs):
    if not _is_valid_arg("server_id_list", kwargs):
        raise UcscValidationException(
            'server_id_list should be specified')


def _set_ts_options_servermemory(ts_cmd_opt, kwargs):
    _validate_servermemory_options(kwargs)
    ts_cmd_opt.server_id_list = str(kwargs["server_id_list"])
    ts_cmd_opt.major_opt_type = \
        SysdebugTechSupportCmdOptConsts.MAJOR_OPT_TYPE_SERVER_MEMORY


def _set_ts_command_options(ts_cmd_opt, kwargs):
    if _is_valid_arg("command_options", kwargs):
        ts_cmd_opt.command_options = str(kwargs["command_options"])


def _set_ts_options(option, ts_cmd_opt, kwargs):
    if option == "ucsm":
        _set_ts_options_ucsm(ts_cmd_opt, kwargs)
    elif option == "ucsm-mgmt":
        _set_ts_options_ucsm_mgmt(ts_cmd_opt, kwargs)
    elif option == "chassis":
        _set_ts_options_chassis(ts_cmd_opt, kwargs)
    elif option == "fabric-extender":
        _set_ts_options_fex(ts_cmd_opt, kwargs)
    elif option == "rack-server":
        _set_ts_options_rackserver(ts_cmd_opt, kwargs)
    elif option == "server-memory":
        _set_ts_options_servermemory(ts_cmd_opt, kwargs)
    else:
        raise UcscValidationException(
            'Unrecognised option value: ' + option)

    _set_ts_command_options(ts_cmd_opt, kwargs)


def poll_wait_for_domain_tech_support_init(handle, creation_ts, ts_domain_mo):
    duration = 30
    poll_interval = 2
    ts_mo = []
    filter_str = '(creation_ts, %s, type="eq")' % (str(creation_ts))
    while True:
        ts_mo = handle.query_classid("SysdebugTechSupport",
                                     filter_str=filter_str, dme="resource-mgr")
        if ts_mo != []:
            break
        time.sleep(min(duration, poll_interval))
        duration = max(0, (duration - poll_interval))
        if duration == 0:
            _fail_and_remove_domain_ts(
                handle, ts_domain_mo, 'failed')

    log.debug("Techsupport creation for domain initiated")
    return ts_mo


def poll_wait_for_domain_tech_support(handle, ts_mo, ts_domain_mo, timeout):
    # poll for tech support mo to complete
    from ..mometa.sysdebug.SysdebugTechSupport import \
        SysdebugTechSupportConsts as SysdebugTechSupportConsts
    duration = timeout
    poll_interval = 5
    while True:
        ts = handle.query_dn(ts_mo.dn, dme="resource-mgr")
        if ts.oper_state == \
                SysdebugTechSupportConsts.OPER_STATE_AVAILABLE:
            break
        if ts.oper_state == \
                SysdebugTechSupportConsts.OPER_STATE_FAILED or \
                ts.oper_state == \
                SysdebugTechSupportConsts.OPER_STATE_UNAVAILABLE:
            _fail_and_remove_domain_ts(handle, ts_domain_mo, 'failed')
        time.sleep(min(duration, poll_interval))
        duration = max(0, (duration - poll_interval))
        if duration == 0:
            ts_domain_mo = handle.query_dn(ts_domain_mo.dn)
            _fail_and_remove_domain_ts(handle, ts_domain_mo, 'failed')

    log.debug("Techsupport creation completed")
    return ts


def get_domain_tech_support(handle, domain_ip,
                            domain_name=None,
                            option="ucsm",
                            timeout=1200,
                            **kwargs):
    """
    This operation creates the technical support file for
    the specified Ucs Domain with specific parameters.
    Note: No support for download tech support file from domain for now


    Args:
        handle (UcscHandle): UcsCentral connection handle
        domain_ip (str): IP of domain, it can be None provided domain_name is
                            valid
        domain_name (str): Name of domain, applicable only if domain_ip is None
        option (str): categorty of technical support to be created.
                      possible values:
                        - ucsm
                        - ucsm-mgmt
                        - chassis:
                            Mandates that user specifies "chassis_id"
                            Either "cimc_id" or "iom_id" or "cartridge_id"
                            When specific "cartridge_id" is given, instead of
                                "all",
                            mandatory "cartridge_cimc_id" must also be given
                        - fabric-extender
                            Mandates that user specifies "fex_id"
                        - rack-server
                            Mandates that user specifies "rack_server_id"
                        - server-memory
                            Mandates that user specifies "server_id_list"
        kwargs: key=value pairs relevant to the seleced option

    Example:

        get_domain_tech_support(handle, domain_ip='192.168.1.1'
                                option="ucsm")

        get_domain_tech_support(handle, domain_ip=None,
                                domain_name="test_domain", option="ucs-mgmt")

        get_domain_tech_support(handle, domain_ip = '192.168.1.1',
                                option="chassis",
                                file_dir=".",
                                file_name="techsupport.tar",
                                chassis_id=1,
                                cimc_id=1,
                                adapter_id=1)

    """

    from .ucscdomain import get_domain, _is_domain_available

    domain = get_domain(handle, domain_ip, domain_name)

    if _is_domain_available(handle, domain.id):
        domain_dn = domain.dn
    else:
        raise UcscOperationError(
            "Get domain techsupport",
            "Domain with IP %s or name %s not registered or "
            "lost visibility with UcsCentral" %
            (domain_ip, domain_name))

    creation_ts = _get_creation_ts()
    ts_domain_mo = _bootstrap_domain_tech_support_mo(
        creation_ts, domain_dn=domain_dn)
    ts_cmd_opt = SysdebugTechSupportCmdOpt(parent_mo_or_dn=ts_domain_mo)
    _set_ts_options(option, ts_cmd_opt, kwargs)

    handle.add_mo(ts_domain_mo)
    handle.commit()

    log.debug("Techsupport creation started")
    # poll for tech support mo to get initiated, it should return list with
    # one element
    ts_mo_list = poll_wait_for_domain_tech_support_init(
        handle, creation_ts, ts_domain_mo)

    # poll for tech support operation to get completed
    poll_wait_for_domain_tech_support(
        handle, ts_mo_list[0], ts_domain_mo, timeout)



"""This module contains the general information for StorageEnclosureDiskSlotEp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StorageEnclosureDiskSlotEpConsts():
    AUTO_ZONE_CAUSE_HDD_TRAY_IN_LIEU_OF_SERVER2 = "hdd-tray-in-lieu-of-server2"
    AUTO_ZONE_CAUSE_HDDSLOT_UNASSIGNED = "hddslot-unassigned"
    AUTO_ZONE_CAUSE_HOTSPARE_UNSUPPORTED = "hotspare-unsupported"
    AUTO_ZONE_CAUSE_MEZZ_CONTROLLER_IN_IOEXPANDER = "mezz-controller-in-ioexpander"
    AUTO_ZONE_CAUSE_NONE = "none"
    AUTO_ZONE_CAUSE_SECOND_CONTROLLER_ABSENT = "second-controller-absent"
    AUTO_ZONE_CAUSE_SHARING_UNSUPPORTED = "sharing-unsupported"
    CONFIGURATION_NOT_SUPPORTED = "not-supported"
    CONFIGURATION_SUPPORTED = "supported"
    CONFIGURATION_UNKNOWN = "unknown"
    LC_ALLOCATED = "allocated"
    LC_AVAILABLE = "available"
    LC_DEALLOCATED = "deallocated"
    LC_REPURPOSED = "repurposed"
    OPERABILITY_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPERABILITY_AUTO_UPGRADE = "auto-upgrade"
    OPERABILITY_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPERABILITY_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPERABILITY_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPERABILITY_CONFIG = "config"
    OPERABILITY_DECOMISSIONING = "decomissioning"
    OPERABILITY_DEGRADED = "degraded"
    OPERABILITY_DISABLED = "disabled"
    OPERABILITY_DISCOVERY = "discovery"
    OPERABILITY_DISCOVERY_FAILED = "discovery-failed"
    OPERABILITY_EQUIPMENT_PROBLEM = "equipment-problem"
    OPERABILITY_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPERABILITY_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPERABILITY_IDENTIFY = "identify"
    OPERABILITY_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPERABILITY_INOPERABLE = "inoperable"
    OPERABILITY_MALFORMED_FRU = "malformed-fru"
    OPERABILITY_NOT_SUPPORTED = "not-supported"
    OPERABILITY_OPERABLE = "operable"
    OPERABILITY_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPERABILITY_PERFORMANCE_PROBLEM = "performance-problem"
    OPERABILITY_POST_FAILURE = "post-failure"
    OPERABILITY_POWER_PROBLEM = "power-problem"
    OPERABILITY_POWERED_OFF = "powered-off"
    OPERABILITY_REMOVED = "removed"
    OPERABILITY_THERMAL_PROBLEM = "thermal-problem"
    OPERABILITY_UNKNOWN = "unknown"
    OPERABILITY_UPGRADE_PROBLEM = "upgrade-problem"
    OPERABILITY_VOLTAGE_PROBLEM = "voltage-problem"
    OWNERSHIP_CHASSIS_DEDICATED_SPARE = "chassis-dedicated-spare"
    OWNERSHIP_CHASSIS_GLOBAL_SPARE = "chassis-global-spare"
    OWNERSHIP_DEDICATED = "dedicated"
    OWNERSHIP_SHARED = "shared"
    OWNERSHIP_UNASSIGNED = "unassigned"
    OWNERSHIP_UNKNOWN = "unknown"
    PRESENCE_EMPTY = "empty"
    PRESENCE_EQUIPPED = "equipped"
    PRESENCE_EQUIPPED_IDENTITY_UNESTABLISHABLE = "equipped-identity-unestablishable"
    PRESENCE_EQUIPPED_NOT_PRIMARY = "equipped-not-primary"
    PRESENCE_EQUIPPED_SLAVE = "equipped-slave"
    PRESENCE_EQUIPPED_UNSUPPORTED = "equipped-unsupported"
    PRESENCE_EQUIPPED_WITH_MALFORMED_FRU = "equipped-with-malformed-fru"
    PRESENCE_INACCESSIBLE = "inaccessible"
    PRESENCE_MISMATCH = "mismatch"
    PRESENCE_MISMATCH_IDENTITY_UNESTABLISHABLE = "mismatch-identity-unestablishable"
    PRESENCE_MISMATCH_SLAVE = "mismatch-slave"
    PRESENCE_MISSING = "missing"
    PRESENCE_MISSING_SLAVE = "missing-slave"
    PRESENCE_NOT_SUPPORTED = "not-supported"
    PRESENCE_UNAUTHORIZED = "unauthorized"
    PRESENCE_UNKNOWN = "unknown"


class StorageEnclosureDiskSlotEp(ManagedObject):
    """This is StorageEnclosureDiskSlotEp class."""

    consts = StorageEnclosureDiskSlotEpConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("StorageEnclosureDiskSlotEp", "storageEnclosureDiskSlotEp", "disk-slot-[id]", VersionMeta.Version131a, "InputOutput", 0x1f, [], ["read-only"], ['storageEnclosure'], ['storageControllerRef'], ["Get"])

    prop_meta = {
        "auto_zone_cause": MoPropertyMeta("auto_zone_cause", "autoZoneCause", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["hdd-tray-in-lieu-of-server2", "hddslot-unassigned", "hotspare-unsupported", "mezz-controller-in-ioexpander", "none", "second-controller-absent", "sharing-unsupported"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "configuration": MoPropertyMeta("configuration", "configuration", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-supported", "supported", "unknown"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x4, None, None, None, [], []), 
        "lc": MoPropertyMeta("lc", "lc", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["allocated", "available", "deallocated", "repurposed"], []), 
        "oper_qualifier_reason": MoPropertyMeta("oper_qualifier_reason", "operQualifierReason", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "operability": MoPropertyMeta("operability", "operability", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "malformed-fru", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "upgrade-problem", "voltage-problem"], []), 
        "ownership": MoPropertyMeta("ownership", "ownership", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["chassis-dedicated-spare", "chassis-global-spare", "dedicated", "shared", "unassigned", "unknown"], []), 
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "presence": MoPropertyMeta("presence", "presence", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "equipped", "equipped-identity-unestablishable", "equipped-not-primary", "equipped-slave", "equipped-unsupported", "equipped-with-malformed-fru", "inaccessible", "mismatch", "mismatch-identity-unestablishable", "mismatch-slave", "missing", "missing-slave", "not-supported", "unauthorized", "unknown"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "autoZoneCause": "auto_zone_cause", 
        "childAction": "child_action", 
        "configuration": "configuration", 
        "dn": "dn", 
        "id": "id", 
        "lc": "lc", 
        "operQualifierReason": "oper_qualifier_reason", 
        "operability": "operability", 
        "ownership": "ownership", 
        "peerDn": "peer_dn", 
        "presence": "presence", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.auto_zone_cause = None
        self.child_action = None
        self.configuration = None
        self.lc = None
        self.oper_qualifier_reason = None
        self.operability = None
        self.ownership = None
        self.peer_dn = None
        self.presence = None
        self.status = None

        ManagedObject.__init__(self, "StorageEnclosureDiskSlotEp", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import unittest

from nose.tools import assert_equal
from ucscsdk.ucscmeta import VersionMeta
from ucscsdk.ucsccoremeta import UcscVersion

class TestVersion(unittest.TestCase):
    def test_nightly_version1(self):
        version1 = UcscVersion("2.0(13aS6)")
        version2 = UcscVersion("3.0(1S10)")
        assert_equal((version1 < version2), True)


    def test_nightly_version2(self):
        version1 = UcscVersion("2.0(13aS6)")
        version2 = UcscVersion("2.0(1S10)")
        assert_equal((version1 > version2), True)


    def test_nightly_version3(self):
        # 2.0(2cS6) will be considered as 2.0(2d) internally
        version1 = UcscVersion("2.0(2cS6)")
        version2 = UcscVersion("2.0(2c)")
        assert_equal((version1 == version2), False)


    def test_nightly_version4(self):
        version1 = UcscVersion("2.0(2cS6)")
        version2 = UcscVersion("2.0(3)")
        assert_equal((version1 < version2), True)


    def test_spin_version1(self):
        # version interpreted as 4.0(2b)
        version1 = UcscVersion("4.0(2aS3)")
        version2 = UcscVersion("4.0(2b)")
        assert_equal((version1 == version2), True)


    def test_spin_version2(self):
        # version interpreted as 4.0(234c)
        version1 = UcscVersion("4.0(234bS3)")
        version2 = UcscVersion("4.0(234c)")
        assert_equal((version1 == version2), True)


    def test_spin_version3(self):
        # version interpreted as 4.0(2z)
        version1 = UcscVersion("4.0(2S3)")
        version2 = UcscVersion("4.0(2z)")
        assert_equal((version1 == version2), True)


    def test_spin_version4(self):
        # version interpreted as 4.0(234z)
        version1 = UcscVersion("4.0(234S3)")
        version2 = UcscVersion("4.0(234z)")
        assert_equal((version1 == version2), True)


    def test_patch_version1(self):
        # version interpreted as 4.0(235a)
        version1 = UcscVersion("4.0(234.5)")
        version2 = UcscVersion("4.0(235a)")
        assert_equal((version1 == version2), True)


    def test_build_version1(self):
        # 4.2(0.175a) is an engineering build that will later become 4.2(1a)
        version1 = UcscVersion("4.2(0.175a)")
        version2 = UcscVersion("4.2(1a)")
        assert_equal((version1 < version2), True)


    def test_build_version2(self):
        version1 = UcscVersion("4.2(0.175a)")
        version2 = UcscVersion("4.2(0.258a)")
        assert_equal((version1 < version2), True)


    def test_spin_version5(self):
        # version interpreted as 4.2(2a)
        version1 = UcscVersion("4.2(1.2021052301)")
        version2 = UcscVersion("4.2(2a)")
        assert_equal((version1 == version2), True)


    def test_spin_version6(self):
        # version interpreted as 4.2(1b)
        version1 = UcscVersion("4.2(1a.2021052301)")
        version2 = UcscVersion("4.2(1b)")
        assert_equal((version1 == version2), True)


    def test_gt_same_major_version(self):
        version1 = VersionMeta.Version201b
        version2 = VersionMeta.Version201o
        assert_equal((version1 < version2), True)


    def test_gt_different_major_version(self):
        version1 = VersionMeta.Version151a
        version2 = VersionMeta.Version201l
        assert_equal((version1 < version2), True)


    def test_patch_versions(self):
        # when we don't see a patch version we use z
        # so 2.0(12) will be considered as 2.0(12z)
        version1 = UcscVersion("2.0(12b)")
        version2 = UcscVersion("2.0(12)")
        assert_equal((version1 > version2), False)


    def test_version_parsing(self):
                test_cases = [
                    ("1.0(0.0a)", {"major": "1", "minor": "0", "mr": "0", "patch": "a", "spin": None, "build": "0"}),
                    ("12.34(56.78z)", {"major": "12", "minor": "34", "mr": "56", "patch": "z", "spin": None, "build": "78"}),
                    ("123.456(789.0b)", {"major": "123", "minor": "456", "mr": "789", "patch": "b", "spin": None, "build": "0"}),
                    ("2.0(13aS1)", {"major": "2", "minor": "0", "mr": "13", "patch": "b", "spin": "S1", "build": None}),
                    ("3.0(1S10)", {"major": "3", "minor": "0", "mr": "1", "patch": "z", "spin": "S10", "build": None}),
                    ("66.77(67.1582251418)", {"major": "66", "minor": "77", "mr": "68", "patch": "a", "spin": None, "build": None}),
                    ("4.2(0.175a)", {"major": "4", "minor": "2", "mr": "0", "patch": "a", "spin": None, "build": "175"}),
                    ("4.2(1.2021052301)", {"major": "4", "minor": "2", "mr": "2", "patch": "a", "spin": None, "build": None}),
                    ("4.2(1a.2021052301)", {"major": "4", "minor": "2", "mr": "1", "patch": "b", "spin": "2021052301", "build": None}),
                ]

                for version_str, expected in test_cases:
                    with self.subTest(version_str=version_str):
                        version = UcscVersion(version_str)
                        self.assertEqual(version.major, expected["major"])
                        self.assertEqual(version.minor, expected["minor"])
                        self.assertEqual(version.mr, expected["mr"])
                        self.assertEqual(version.patch, expected["patch"])
                        self.assertEqual(version.spin, expected["spin"])
                        self.assertEqual(version.build, expected["build"])



"""This module contains the general information for FabricVlanReq ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FabricVlanReqConsts():
    TYPE_LAN = "lan"
    TYPE_SAN = "san"


class FabricVlanReq(ManagedObject):
    """This is FabricVlanReq class."""

    consts = FabricVlanReqConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FabricVlanReq", "fabricVlanReq", "vlan-req-[name]", VersionMeta.Version111a, "InputOutput", 0x1f, [], ["admin", "ext-lan-config", "ext-lan-policy", "ls-network"], ['orgOrg'], [], ["Add", "Get", "Remove"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "config_issues": MoPropertyMeta("config_issues", "configIssues", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|permit-unresolved),){0,2}(defaultValue|not-applicable|permit-unresolved){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x4, None, None, r"""[\-\.:_a-zA-Z0-9]{1,32}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lan", "san"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "configIssues": "config_issues", 
        "dn": "dn", 
        "name": "name", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.config_issues = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "FabricVlanReq", parent_mo_or_dn, **kwargs)




"""This module contains the general information for EquipmentLocalDiskDef ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentLocalDiskDefConsts():
    FORCE_UPDATE_VERSION_FALSE = "false"
    FORCE_UPDATE_VERSION_NO = "no"
    FORCE_UPDATE_VERSION_TRUE = "true"
    FORCE_UPDATE_VERSION_YES = "yes"
    ME4308_SUPPORTED_FALSE = "false"
    ME4308_SUPPORTED_NO = "no"
    ME4308_SUPPORTED_TRUE = "true"
    ME4308_SUPPORTED_YES = "yes"
    SELF_ENCRYPTING_DRIVE_FALSE = "false"
    SELF_ENCRYPTING_DRIVE_NO = "no"
    SELF_ENCRYPTING_DRIVE_TRUE = "true"
    SELF_ENCRYPTING_DRIVE_YES = "yes"
    TECHNOLOGY_HDD = "HDD"
    TECHNOLOGY_NVME = "NVME"
    TECHNOLOGY_SSD = "SSD"
    TECHNOLOGY_UNSPECIFIED = "unspecified"


class EquipmentLocalDiskDef(ManagedObject):
    """This is EquipmentLocalDiskDef class."""

    consts = EquipmentLocalDiskDefConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentLocalDiskDef", "equipmentLocalDiskDef", "disk", VersionMeta.Version111a, "InputOutput", 0x1f, [], [""], ['equipmentLocalDiskCapProvider'], [], ["Get"])

    prop_meta = {
        "block_size": MoPropertyMeta("block_size", "blockSize", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "cache_size": MoPropertyMeta("cache_size", "cacheSize", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "capacity": MoPropertyMeta("capacity", "capacity", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "force_update_version": MoPropertyMeta("force_update_version", "forceUpdateVersion", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "link_speed": MoPropertyMeta("link_speed", "linkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "me4308_supported": MoPropertyMeta("me4308_supported", "me4308Supported", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "number_of_blocks": MoPropertyMeta("number_of_blocks", "numberOfBlocks", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "rotational_speed": MoPropertyMeta("rotational_speed", "rotationalSpeed", "float", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "seek_average_read_write": MoPropertyMeta("seek_average_read_write", "seekAverageReadWrite", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "seek_track_to_track_read_write": MoPropertyMeta("seek_track_to_track_read_write", "seekTrackToTrackReadWrite", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "self_encrypting_drive": MoPropertyMeta("self_encrypting_drive", "selfEncryptingDrive", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "technology": MoPropertyMeta("technology", "technology", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["HDD", "NVME", "SSD", "unspecified"], []), 
    }

    prop_map = {
        "blockSize": "block_size", 
        "cacheSize": "cache_size", 
        "capacity": "capacity", 
        "childAction": "child_action", 
        "dn": "dn", 
        "forceUpdateVersion": "force_update_version", 
        "linkSpeed": "link_speed", 
        "me4308Supported": "me4308_supported", 
        "name": "name", 
        "numberOfBlocks": "number_of_blocks", 
        "rn": "rn", 
        "rotationalSpeed": "rotational_speed", 
        "seekAverageReadWrite": "seek_average_read_write", 
        "seekTrackToTrackReadWrite": "seek_track_to_track_read_write", 
        "selfEncryptingDrive": "self_encrypting_drive", 
        "status": "status", 
        "technology": "technology", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.block_size = None
        self.cache_size = None
        self.capacity = None
        self.child_action = None
        self.force_update_version = None
        self.link_speed = None
        self.me4308_supported = None
        self.name = None
        self.number_of_blocks = None
        self.rotational_speed = None
        self.seek_average_read_write = None
        self.seek_track_to_track_read_write = None
        self.self_encrypting_drive = None
        self.status = None
        self.technology = None

        ManagedObject.__init__(self, "EquipmentLocalDiskDef", parent_mo_or_dn, **kwargs)




"""This module contains the general information for AdaptorMenloNetInStatsHist ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class AdaptorMenloNetInStatsHistConsts():
    MOST_RECENT_FALSE = "false"
    MOST_RECENT_NO = "no"
    MOST_RECENT_TRUE = "true"
    MOST_RECENT_YES = "yes"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class AdaptorMenloNetInStatsHist(ManagedObject):
    """This is AdaptorMenloNetInStatsHist class."""

    consts = AdaptorMenloNetInStatsHistConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("AdaptorMenloNetInStatsHist", "adaptorMenloNetInStatsHist", "[id]", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["read-only"], ['adaptorMenloNetInStats'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "drop_fc_lif_invalid": MoPropertyMeta("drop_fc_lif_invalid", "dropFcLifInvalid", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_fc_lif_invalid_delta": MoPropertyMeta("drop_fc_lif_invalid_delta", "dropFcLifInvalidDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_fc_lif_invalid_delta_avg": MoPropertyMeta("drop_fc_lif_invalid_delta_avg", "dropFcLifInvalidDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_fc_lif_invalid_delta_max": MoPropertyMeta("drop_fc_lif_invalid_delta_max", "dropFcLifInvalidDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_fc_lif_invalid_delta_min": MoPropertyMeta("drop_fc_lif_invalid_delta_min", "dropFcLifInvalidDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_fc_multicast": MoPropertyMeta("drop_fc_multicast", "dropFcMulticast", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_fc_multicast_delta": MoPropertyMeta("drop_fc_multicast_delta", "dropFcMulticastDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_fc_multicast_delta_avg": MoPropertyMeta("drop_fc_multicast_delta_avg", "dropFcMulticastDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_fc_multicast_delta_max": MoPropertyMeta("drop_fc_multicast_delta_max", "dropFcMulticastDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_fc_multicast_delta_min": MoPropertyMeta("drop_fc_multicast_delta_min", "dropFcMulticastDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_null_pif": MoPropertyMeta("drop_null_pif", "dropNullPif", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_null_pif_delta": MoPropertyMeta("drop_null_pif_delta", "dropNullPifDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_null_pif_delta_avg": MoPropertyMeta("drop_null_pif_delta_avg", "dropNullPifDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_null_pif_delta_max": MoPropertyMeta("drop_null_pif_delta_max", "dropNullPifDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "drop_null_pif_delta_min": MoPropertyMeta("drop_null_pif_delta_min", "dropNullPifDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "fwd_lookup_no_hit": MoPropertyMeta("fwd_lookup_no_hit", "fwdLookupNoHit", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "fwd_lookup_no_hit_delta": MoPropertyMeta("fwd_lookup_no_hit_delta", "fwdLookupNoHitDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "fwd_lookup_no_hit_delta_avg": MoPropertyMeta("fwd_lookup_no_hit_delta_avg", "fwdLookupNoHitDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "fwd_lookup_no_hit_delta_max": MoPropertyMeta("fwd_lookup_no_hit_delta_max", "fwdLookupNoHitDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "fwd_lookup_no_hit_delta_min": MoPropertyMeta("fwd_lookup_no_hit_delta_min", "fwdLookupNoHitDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "id": MoPropertyMeta("id", "id", "ulong", VersionMeta.Version111a, MoPropertyMeta.NAMING, None, None, None, None, [], []), 
        "most_recent": MoPropertyMeta("most_recent", "mostRecent", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "dropFcLifInvalid": "drop_fc_lif_invalid", 
        "dropFcLifInvalidDelta": "drop_fc_lif_invalid_delta", 
        "dropFcLifInvalidDeltaAvg": "drop_fc_lif_invalid_delta_avg", 
        "dropFcLifInvalidDeltaMax": "drop_fc_lif_invalid_delta_max", 
        "dropFcLifInvalidDeltaMin": "drop_fc_lif_invalid_delta_min", 
        "dropFcMulticast": "drop_fc_multicast", 
        "dropFcMulticastDelta": "drop_fc_multicast_delta", 
        "dropFcMulticastDeltaAvg": "drop_fc_multicast_delta_avg", 
        "dropFcMulticastDeltaMax": "drop_fc_multicast_delta_max", 
        "dropFcMulticastDeltaMin": "drop_fc_multicast_delta_min", 
        "dropNullPif": "drop_null_pif", 
        "dropNullPifDelta": "drop_null_pif_delta", 
        "dropNullPifDeltaAvg": "drop_null_pif_delta_avg", 
        "dropNullPifDeltaMax": "drop_null_pif_delta_max", 
        "dropNullPifDeltaMin": "drop_null_pif_delta_min", 
        "fwdLookupNoHit": "fwd_lookup_no_hit", 
        "fwdLookupNoHitDelta": "fwd_lookup_no_hit_delta", 
        "fwdLookupNoHitDeltaAvg": "fwd_lookup_no_hit_delta_avg", 
        "fwdLookupNoHitDeltaMax": "fwd_lookup_no_hit_delta_max", 
        "fwdLookupNoHitDeltaMin": "fwd_lookup_no_hit_delta_min", 
        "id": "id", 
        "mostRecent": "most_recent", 
        "rn": "rn", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.drop_fc_lif_invalid = None
        self.drop_fc_lif_invalid_delta = None
        self.drop_fc_lif_invalid_delta_avg = None
        self.drop_fc_lif_invalid_delta_max = None
        self.drop_fc_lif_invalid_delta_min = None
        self.drop_fc_multicast = None
        self.drop_fc_multicast_delta = None
        self.drop_fc_multicast_delta_avg = None
        self.drop_fc_multicast_delta_max = None
        self.drop_fc_multicast_delta_min = None
        self.drop_null_pif = None
        self.drop_null_pif_delta = None
        self.drop_null_pif_delta_avg = None
        self.drop_null_pif_delta_max = None
        self.drop_null_pif_delta_min = None
        self.fwd_lookup_no_hit = None
        self.fwd_lookup_no_hit_delta = None
        self.fwd_lookup_no_hit_delta_avg = None
        self.fwd_lookup_no_hit_delta_max = None
        self.fwd_lookup_no_hit_delta_min = None
        self.most_recent = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None

        ManagedObject.__init__(self, "AdaptorMenloNetInStatsHist", parent_mo_or_dn, **kwargs)




"""This module contains the general information for BiosVfPCISlotLinkSpeed ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class BiosVfPCISlotLinkSpeedConsts():
    SUPPORTED_BY_DEFAULT_NO = "no"
    SUPPORTED_BY_DEFAULT_YES = "yes"
    VP_PCIE_SLOT10_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT10_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT10_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT10_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT10_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT10_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT10_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT1_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT1_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT1_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT1_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT1_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT1_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT1_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT2_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT2_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT2_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT2_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT2_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT2_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT2_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT3_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT3_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT3_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT3_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT3_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT3_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT3_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT4_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT4_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT4_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT4_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT4_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT4_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT4_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT5_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT5_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT5_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT5_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT5_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT5_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT5_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT6_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT6_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT6_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT6_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT6_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT6_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT6_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT7_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT7_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT7_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT7_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT7_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT7_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT7_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT8_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT8_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT8_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT8_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT8_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT8_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT8_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT9_LINK_SPEED_AUTO = "auto"
    VP_PCIE_SLOT9_LINK_SPEED_DISABLED = "disabled"
    VP_PCIE_SLOT9_LINK_SPEED_GEN1 = "gen1"
    VP_PCIE_SLOT9_LINK_SPEED_GEN2 = "gen2"
    VP_PCIE_SLOT9_LINK_SPEED_GEN3 = "gen3"
    VP_PCIE_SLOT9_LINK_SPEED_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT9_LINK_SPEED_PLATFORM_RECOMMENDED = "platform-recommended"


class BiosVfPCISlotLinkSpeed(ManagedObject):
    """This is BiosVfPCISlotLinkSpeed class."""

    consts = BiosVfPCISlotLinkSpeedConsts()
    naming_props = set([])

    mo_meta = MoMeta("BiosVfPCISlotLinkSpeed", "biosVfPCISlotLinkSpeed", "PCI-Slot-Link-Speed", VersionMeta.Version121a, "InputOutput", 0x3fff, [], ["read-only"], ['biosVProfile'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version121a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "supported_by_default": MoPropertyMeta("supported_by_default", "supportedByDefault", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "vp_pc_ie_slot10_link_speed": MoPropertyMeta("vp_pc_ie_slot10_link_speed", "vpPCIeSlot10LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
        "vp_pc_ie_slot1_link_speed": MoPropertyMeta("vp_pc_ie_slot1_link_speed", "vpPCIeSlot1LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
        "vp_pc_ie_slot2_link_speed": MoPropertyMeta("vp_pc_ie_slot2_link_speed", "vpPCIeSlot2LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
        "vp_pc_ie_slot3_link_speed": MoPropertyMeta("vp_pc_ie_slot3_link_speed", "vpPCIeSlot3LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
        "vp_pc_ie_slot4_link_speed": MoPropertyMeta("vp_pc_ie_slot4_link_speed", "vpPCIeSlot4LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
        "vp_pc_ie_slot5_link_speed": MoPropertyMeta("vp_pc_ie_slot5_link_speed", "vpPCIeSlot5LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
        "vp_pc_ie_slot6_link_speed": MoPropertyMeta("vp_pc_ie_slot6_link_speed", "vpPCIeSlot6LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
        "vp_pc_ie_slot7_link_speed": MoPropertyMeta("vp_pc_ie_slot7_link_speed", "vpPCIeSlot7LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
        "vp_pc_ie_slot8_link_speed": MoPropertyMeta("vp_pc_ie_slot8_link_speed", "vpPCIeSlot8LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
        "vp_pc_ie_slot9_link_speed": MoPropertyMeta("vp_pc_ie_slot9_link_speed", "vpPCIeSlot9LinkSpeed", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x2000, None, None, None, ["auto", "disabled", "gen1", "gen2", "gen3", "platform-default", "platform-recommended"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "status": "status", 
        "supportedByDefault": "supported_by_default", 
        "vpPCIeSlot10LinkSpeed": "vp_pc_ie_slot10_link_speed", 
        "vpPCIeSlot1LinkSpeed": "vp_pc_ie_slot1_link_speed", 
        "vpPCIeSlot2LinkSpeed": "vp_pc_ie_slot2_link_speed", 
        "vpPCIeSlot3LinkSpeed": "vp_pc_ie_slot3_link_speed", 
        "vpPCIeSlot4LinkSpeed": "vp_pc_ie_slot4_link_speed", 
        "vpPCIeSlot5LinkSpeed": "vp_pc_ie_slot5_link_speed", 
        "vpPCIeSlot6LinkSpeed": "vp_pc_ie_slot6_link_speed", 
        "vpPCIeSlot7LinkSpeed": "vp_pc_ie_slot7_link_speed", 
        "vpPCIeSlot8LinkSpeed": "vp_pc_ie_slot8_link_speed", 
        "vpPCIeSlot9LinkSpeed": "vp_pc_ie_slot9_link_speed", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.status = None
        self.supported_by_default = None
        self.vp_pc_ie_slot10_link_speed = None
        self.vp_pc_ie_slot1_link_speed = None
        self.vp_pc_ie_slot2_link_speed = None
        self.vp_pc_ie_slot3_link_speed = None
        self.vp_pc_ie_slot4_link_speed = None
        self.vp_pc_ie_slot5_link_speed = None
        self.vp_pc_ie_slot6_link_speed = None
        self.vp_pc_ie_slot7_link_speed = None
        self.vp_pc_ie_slot8_link_speed = None
        self.vp_pc_ie_slot9_link_speed = None

        ManagedObject.__init__(self, "BiosVfPCISlotLinkSpeed", parent_mo_or_dn, **kwargs)

